==> buildnotes-1.0.0-1.18.2-sources.jar: net/atif/buildnotes/network/PacketIdentifiers.java <==
package net.atif.buildnotes.network;

import net.atif.buildnotes.Buildnotes;
import net.minecraft.class_2960;

public class PacketIdentifiers {
    // --- Server to Client (S2C) ---
    public static final class_2960 HANDSHAKE_S2C = new class_2960(Buildnotes.MOD_ID, "handshake_s2c");
    public static final class_2960 INITIAL_SYNC_S2C = new class_2960(Buildnotes.MOD_ID, "initial_sync_s2c");
    public static final class_2960 UPDATE_NOTE_S2C = new class_2960(Buildnotes.MOD_ID, "update_note_s2c");
    public static final class_2960 UPDATE_BUILD_S2C = new class_2960(Buildnotes.MOD_ID, "update_build_s2c");
    public static final class_2960 DELETE_NOTE_S2C = new class_2960(Buildnotes.MOD_ID, "delete_note_s2c");
    public static final class_2960 DELETE_BUILD_S2C = new class_2960(Buildnotes.MOD_ID, "delete_build_s2c");


    // --- Client to Server (C2S) ---
    public static final class_2960 REQUEST_DATA_C2S = new class_2960(Buildnotes.MOD_ID, "request_data_c2s");
    public static final class_2960 SAVE_NOTE_C2S = new class_2960(Buildnotes.MOD_ID, "save_note_c2s");
    public static final class_2960 SAVE_BUILD_C2S = new class_2960(Buildnotes.MOD_ID, "save_build_c2s");
    public static final class_2960 DELETE_NOTE_C2S = new class_2960(Buildnotes.MOD_ID, "delete_note_c2s");
    public static final class_2960 DELETE_BUILD_C2S = new class_2960(Buildnotes.MOD_ID, "delete_build_c2s");


    // Image Transfer Packets
    // Client to Server: Here is the data for an image I want to save.
    public static final class_2960 UPLOAD_IMAGE_C2S = new class_2960(Buildnotes.MOD_ID, "upload_image_c2s");
    // Client to Server: I don't have this image, please send it to me.
    public static final class_2960 REQUEST_IMAGE_C2S = new class_2960(Buildnotes.MOD_ID, "request_image_c2s");
    // Server to Client: Here is the image data you requested.
    public static final class_2960 IMAGE_DATA_S2C = new class_2960(Buildnotes.MOD_ID, "image_data_s2c");
}

==> buildnotes-1.1.0-1.19-sources.jar: net/atif/buildnotes/network/PacketIdentifiers.java <==
package net.atif.buildnotes.network;

import net.atif.buildnotes.Buildnotes;
import net.minecraft.class_2960;

public class PacketIdentifiers {
    // --- Server to Client (S2C) ---
    public static final class_2960 HANDSHAKE_S2C = new class_2960(Buildnotes.MOD_ID, "handshake_s2c");
    public static final class_2960 INITIAL_SYNC_S2C = new class_2960(Buildnotes.MOD_ID, "initial_sync_s2c");
    public static final class_2960 UPDATE_NOTE_S2C = new class_2960(Buildnotes.MOD_ID, "update_note_s2c");
    public static final class_2960 UPDATE_BUILD_S2C = new class_2960(Buildnotes.MOD_ID, "update_build_s2c");
    public static final class_2960 DELETE_NOTE_S2C = new class_2960(Buildnotes.MOD_ID, "delete_note_s2c");
    public static final class_2960 DELETE_BUILD_S2C = new class_2960(Buildnotes.MOD_ID, "delete_build_s2c");


    // --- Client to Server (C2S) ---
    public static final class_2960 REQUEST_DATA_C2S = new class_2960(Buildnotes.MOD_ID, "request_data_c2s");
    public static final class_2960 SAVE_NOTE_C2S = new class_2960(Buildnotes.MOD_ID, "save_note_c2s");
    public static final class_2960 SAVE_BUILD_C2S = new class_2960(Buildnotes.MOD_ID, "save_build_c2s");
    public static final class_2960 DELETE_NOTE_C2S = new class_2960(Buildnotes.MOD_ID, "delete_note_c2s");
    public static final class_2960 DELETE_BUILD_C2S = new class_2960(Buildnotes.MOD_ID, "delete_build_c2s");

    // Image Transfer Packets
    public static final class_2960 UPLOAD_IMAGE_CHUNK_C2S = new class_2960(Buildnotes.MOD_ID, "upload_image_chunk_c2s");
    public static final class_2960 REQUEST_IMAGE_C2S = new class_2960(Buildnotes.MOD_ID, "request_image_c2s");
    public static final class_2960 IMAGE_CHUNK_S2C = new class_2960(Buildnotes.MOD_ID, "image_chunk_s2c");
    public static final class_2960 IMAGE_NOT_FOUND_S2C = new class_2960(Buildnotes.MOD_ID, "image_not_found_s2c");
}
